==> phpMyGPX-0.3.tar.bz2: phpmygpx/bookmark.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', './' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);

session_start();

include("./config.inc.php");
include("./libraries/functions.inc.php");
include("./libraries/classes.php");
include("./libraries/html.classes.php");
include("./bookmark.html.php");

setlocale (LC_TIME, $cfg['config_locale']);
include("./languages/".get_lang($cfg['config_language']).".php");
include("./head.html.php");

if($cfg['show_exec_time'])
    $startTime = microtime_float();

if($DEBUG) {
    foreach($_POST as $akey => $val)
        out("<b>$akey</b> = $val", "OUT_DEBUG");
}

$p = intval($_GET['p']);
$id = intval($_GET['id']);
$task = strip_tags($_GET['task']);
$url = strip_tags($_GET['url']);
$name = strip_tags($_GET['name']);

// connect to database
$link = db_connect_h($cfg['db_host'], $cfg['db_name'], $cfg['db_user'], $cfg['db_password']);

HTML::heading(_APP_NAME, 2);
HTML::main_menu();

switch ($task) {
	case 'add':
		addBookmark($url, $name);
		break;
	case 'delete':
		deleteBookmark($id);
		break;
	case 'list':
	default:
        listBookmarks($p);
		break;
}


function addBookmark($url, $name) {
	global $cfg;
    HTML::heading(_MENU_BOOKM_ADD, 3);
	if($url) {
		if(!$cfg['public_host'] || check_password($cfg['admin_password'])) {
    		// insert bookmark into database
	        $query = "INSERT IGNORE INTO `${cfg['db_table_prefix']}bookmarks` SET 
	        	`name` = '".$name."', 
	        	`url` = '".$url."',
	        	`latitude` = '0', 
	        	`longitude` = '0',
	        	`zoom` = '0', 
	        	`timestamp` = NOW(),
	        	`public` = '1' ;";
	        $result = db_query($query);
	        $bookmark_id = mysql_insert_id();
			HTML::message(_BOOKM_ADDED);
			HTML::message("<a href='javascript:history.back();'>"._CMN_PREV."</a>");
		}else {
			HTML::message(_NOT_AUTH ." ". _DO_LOGIN);
		}
	}else {
		HTML::message(_BOOKM_NO_URL);
	}
}

function deleteBookmark($id) {
	global $cfg;
    HTML::heading(_MENU_BOOKM_DELETE, 3);
	if(!$cfg['public_host'] || check_password($cfg['admin_password'])) {
		// delete bookmark
        $query = "DELETE IGNORE FROM `${cfg['db_table_prefix']}bookmarks` 
        	WHERE `id` = '$id' ;";
        $result = db_query($query);
		HTML::message(_BOOKM_DELETED);
	}else {
		HTML::message(_NOT_AUTH ." ". _DO_LOGIN);
	}
}

function listBookmarks($page) {
	global $cfg;
    HTML::heading(_MENU_BOOKM_VIEW, 3);
	$search_url = "";
	$limit = $cfg['result_table_limit'];
    $query = "SELECT SQL_CALC_FOUND_ROWS * FROM `${cfg['db_table_prefix']}bookmarks` ";
	if($option == "filter") {
		$query .= "WHERE `name` LIKE '%$description%' ";
		$search_url = "&option=filter&description=$description";
	}
	$query .= "ORDER BY `id` ASC LIMIT ". ($page*$limit) .", $limit ;";
    $result = db_query($query);
	if($DEBUG)	out($query, 'OUT_DEBUG');
    if(mysql_num_rows($result)) {
		$num_found = mysql_result(db_query("SELECT FOUND_ROWS();") ,0);
		HTML::viewPagination($page, ceil($num_found/$limit), 
			'bookmarks.php?task=list'.$search_url);
		HTML_bookmarks::viewBookmarksTableHeader();
		while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
			HTML_bookmarks::viewBookmarksTableRow($row);
		}
		HTML_bookmarks::viewBookmarksTableFooter();
		HTML::viewPagination($page, ceil($num_found/$limit), 
			'bookmarks.php?task=list'.$search_url);
		HTML::message($num_found ._DB_BOOKM_AVAILABLE);
	}
	else
		HTML::message(_BOOKM_NONE_IN_DB);
}


if($cfg['show_exec_time']) {
    $endTime = microtime_float();
    $exectime = round($endTime - $startTime, 4);
}
include("./foot.html.php");
?>

==> phpMyGPX-0.5.tar.bz2: phpmygpx/bookmark.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', './' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);

session_start();

include("./config.inc.php");
include("./libraries/functions.inc.php");
include("./libraries/classes.php");
include("./libraries/html.classes.php");
include("./bookmark.html.php");

setlocale (LC_TIME, $cfg['config_locale']);
include("./languages/".get_lang($cfg['config_language']).".php");
include("./head.html.php");

if($cfg['show_exec_time'])
    $startTime = microtime_float();

if($DEBUG) {
    foreach($_POST as $akey => $val)
        out("<b>$akey</b> = $val", "OUT_DEBUG");
}

$p = intval($_GET['p']);
$id = intval($_GET['id']);
$task = strip_tags($_GET['task']);
$url = strip_tags($_GET['url']);
$name = strip_tags(urldecode($_GET['name']));

// connect to database
$link = db_connect_h($cfg['db_host'], $cfg['db_name'], $cfg['db_user'], $cfg['db_password']);

if(!$cfg['embedded_mode']) {
	HTML::heading(_APP_NAME, 2);
	HTML::main_menu();
}

switch ($task) {
	case 'add':
		addBookmark($url, $name);
		break;
	case 'delete':
		deleteBookmark($id);
		break;
	case 'list':
	default:
        listBookmarks($p);
		break;
}


function addBookmark($url, $name) {
	global $cfg;
    HTML::heading(_MENU_BOOKM_ADD, 3);
	if($url) {
		if(!$cfg['public_host'] || check_password($cfg['admin_password'])) {
    		// insert bookmark into database
	        $query = "INSERT IGNORE INTO `${cfg['db_table_prefix']}bookmarks` SET 
	        	`name` = '".$name."', 
	        	`url` = '".$url."',
	        	`latitude` = '0', 
	        	`longitude` = '0',
	        	`zoom` = '0', 
	        	`timestamp` = NOW(),
	        	`public` = '1' ;";
	        $result = db_query($query);
	        $bookmark_id = mysql_insert_id();
			HTML::message(_BOOKM_ADDED);
			HTML::message("<a href='".$url."'>"._CMN_BACK."</a>");
		}else {
			HTML::message(_NOT_AUTH ." ". _DO_LOGIN);
		}
	}else {
		HTML::message(_BOOKM_NO_URL);
	}
}

function deleteBookmark($id) {
	global $cfg;
    HTML::heading(_MENU_BOOKM_DELETE, 3);
	if(!$cfg['public_host'] || check_password($cfg['admin_password'])) {
		// delete bookmark
        $query = "DELETE IGNORE FROM `${cfg['db_table_prefix']}bookmarks` 
        	WHERE `id` = '$id' ;";
        $result = db_query($query);
		HTML::message(_BOOKM_DELETED);
	}else {
		HTML::message(_NOT_AUTH ." ". _DO_LOGIN);
	}
}

function listBookmarks($page) {
	global $cfg;
    HTML::heading(_MENU_BOOKM_VIEW, 3);
	$search_url = "";
	$limit = $cfg['result_table_limit'];
    $query = "SELECT SQL_CALC_FOUND_ROWS * FROM `${cfg['db_table_prefix']}bookmarks` ";
	if($option == "filter") {
		$query .= "WHERE `name` LIKE '%$description%' ";
		$search_url = "&option=filter&description=$description";
	}
	$query .= "ORDER BY `id` ASC LIMIT ". ($page*$limit) .", $limit ;";
    $result = db_query($query);
	if($DEBUG)	out($query, 'OUT_DEBUG');
    if(mysql_num_rows($result)) {
		$num_found = mysql_result(db_query("SELECT FOUND_ROWS();") ,0);
		HTML::viewPagination($page, ceil($num_found/$limit), 
			'bookmark.php?task=list'.$search_url);
		HTML_bookmarks::viewBookmarksTableHeader();
		while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
			HTML_bookmarks::viewBookmarksTableRow($row);
		}
		HTML_bookmarks::viewBookmarksTableFooter();
		HTML::viewPagination($page, ceil($num_found/$limit), 
			'bookmark.php?task=list'.$search_url);
		HTML::message($num_found ._DB_BOOKM_AVAILABLE);
	}
	else
		HTML::message(_BOOKM_NONE_IN_DB);
}


if($cfg['show_exec_time']) {
    $endTime = microtime_float();
    $exectime = round($endTime - $startTime, 4);
}
include("./foot.html.php");
?>
